## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(cache = TRUE, autodep = TRUE, cache.lazy = FALSE)

## ----warning=FALSE, message=FALSE---------------------------------------------
library(SpatialExperimentIO)
library(SpatialExperiment)
# library(ggplot2)

## ----eval=FALSE---------------------------------------------------------------
#  # ### DO NOT RUN. Example code.
#  # xepath <- "/path/to/folder"
#  # # a. Xenium as SPE
#  # xe_spe <- readXeniumSXE(dirname = xepath)
#  # #    Subset to no control genes
#  # xe_spe <- xe_spe[rowData(xe_spe)$Type == "Gene Expression"]
#  #
#  # # b. Xenium as SCE
#  # xe_sce <- readXeniumSXE(dirname = xepath, return_type = "SCE")
#  # #    Subset to no control genes
#  # xe_sce <- xe_sce[rowData(xe_sce)$Type == "Gene Expression"]

## ----eval=FALSE---------------------------------------------------------------
#  # ### DO NOT RUN. Example code.
#  # cospath <- "/path/to/folder"
#  # # a. CosMx as SPE
#  # cos_spe <- readCosmxSXE(dirname = cospath)
#  #
#  # # b. CosMx as SCE
#  # cos_sce <- readCosmxSXE(dirname = cospath, return_type = "SCE")

## ----eval=FALSE---------------------------------------------------------------
#  # ### DO NOT RUN. Example code.
#  # merpath <- "/path/to/folder"
#  # # a. MERSCOPE as SPE
#  # mer_spe <- readMerscopeSXE(dirname = merpath)
#  #
#  # # b. MERSCOPE as SCE
#  # mer_sce <- readMerscopeSXE(dirname = merpath, return_type = "SCE")
#  

## -----------------------------------------------------------------------------
xepath <- system.file(
  file.path("extdata", "Xenium_small"),
  package = "SpatialExperimentIO")

list.files(xepath)

## -----------------------------------------------------------------------------
# # read the count matrix .h5 file - automatically DropletUtils::read10xCounts(type = "HDF5")
# xe_spe <- readXeniumSXE(dirname = xepath, 
#                         return_type = "SPE",
#                         countmatfpattern = "cell_feature_matrix.h5", 
#                         metadatafpattern = "cells.csv.gz", 
#                         coord_names = c("x_centroid", "y_centroid"))

xe_spe <- readXeniumSXE(dirname = xepath)
xe_spe

## -----------------------------------------------------------------------------
# Subset to no control genes                         
xe_spe <- xe_spe[rowData(xe_spe)$Type == "Gene Expression"]
xe_spe

## -----------------------------------------------------------------------------
# list.files(file.path(xepath, "cell_feature_matrix"))
# "barcodes.tsv.gz" "features.tsv.gz" "matrix.mtx.gz"

## -----------------------------------------------------------------------------
# # or read the count matrix folder - automatically DropletUtils::read10xCounts(type = "sparse") 
# xe_spe <- readXeniumSXE(dirname = xepath, 
#                         countmatfpattern = "cell_feature_matrix")
# # Subset to no control genes                         
# xe_spe <- xe_spe[rowData(xe_spe)$Type == "Gene Expression"]
# xe_spe

## -----------------------------------------------------------------------------
xe_sce <- readXeniumSXE(dirname = xepath, return_type = "SCE")
xe_sce <- xe_sce[rowData(xe_sce)$Type == "Gene Expression"]
xe_sce

## -----------------------------------------------------------------------------
cospath <- system.file(
  file.path("extdata", "CosMx_small"),
  package = "SpatialExperimentIO")

list.files(cospath)

## -----------------------------------------------------------------------------
# cos_spe <- readCosmxSXE(dirname = cospath,
#                         return_type = "SPE",
#                         countmatfpattern = "exprMat_file.csv",
#                         metadatafpattern = "metadata_file.csv",
#                         coord_names = c("CenterX_global_px",
#                                         "CenterY_global_px"))

cos_spe <- readCosmxSXE(dirname = cospath)
cos_spe

## -----------------------------------------------------------------------------
cos_sce <- readCosmxSXE(dirname = cospath, return_type = "SCE")
cos_sce

## -----------------------------------------------------------------------------
merpath <- system.file(
  file.path("extdata", "MERSCOPE_small"),
  package = "SpatialExperimentIO")

list.files(merpath)

## -----------------------------------------------------------------------------
# mer_spe <- readMerscopeSXE(dirname = merpath, 
#                            return_type = "SPE",
#                            countmatfpattern = "cell_by_gene.csv", 
#                            metadatafpattern = "cell_metadata.csv", 
#                            coord_names = c("center_x", "center_y"))

mer_spe <- readMerscopeSXE(dirname = merpath)
mer_spe

## -----------------------------------------------------------------------------
mer_sce <- readMerscopeSXE(dirname = merpath, return_type = "SCE")
mer_sce

## -----------------------------------------------------------------------------
starpath <- system.file(
  file.path("extdata", "STARmapPLUS_small"),
  package = "SpatialExperimentIO")

list.files(starpath)

## -----------------------------------------------------------------------------
# readStarmapplusSXE <- function(dirname = dirname, 
#                                return_type = "SPE",
#                                countmatfpattern = "raw_expression_pd.csv", 
#                                metadatafpattern = "spatial.csv", 
#                                coord_names = c("X", "Y", "Z"))

star_spe <- readStarmapplusSXE(dirname = starpath)
star_spe

## -----------------------------------------------------------------------------
star_sce <- readStarmapplusSXE(dirname = starpath, return_type = "SCE")
star_sce

## ----tidy = TRUE--------------------------------------------------------------
sessionInfo()

